﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace RCM {
    [DisplayName("Start WinBox")]
    public class WinBoxAction : IAction {
        private WinBox _winbox;
        private WinBoxConfig _config;

        public WinBoxAction(WinBox winbox) {
            _winbox = winbox;
            _config = (WinBoxConfig)Config.ConfigSections[typeof(WinBoxConfig)];
        }

        public async void Run() {
            await Task.Run(() => {
                if (string.IsNullOrWhiteSpace(_config.WinBoxPath)) {
                    MessageBox.Show("WinBox path is not set", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
                if (!File.Exists(_config.WinBoxPath)) {
                    MessageBox.Show("WinBox path does not exist", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
                if (Environment.OSVersion.Platform == PlatformID.Unix) {
                    RunUnix();
                } else {
                    RunWin();
                }
            });
        }

        private void RunWin() {
            string winboxParam = string.Format("\"{0}\" \"{1}\" \"{2}\"", _winbox.Host, _winbox.Username, _winbox.Password);
            Process.Start(_config.WinBoxPath, winboxParam);
        }

        private void RunUnix() {
            string winboxParam = string.Format("\"{0}\" \"{1}\" \"{2}\" \"{3}\"", _config.WinBoxPath, _winbox.Host, _winbox.Username, _winbox.Password);
            Process.Start("wine", winboxParam);
        }
    }
}
